@@ -12,8 +12,6 @@ use byte_slice_cast::{AsSliceOf, FromByteSlice};
 use log::{info, warn};
 use mapr::{Mmap, MmapMut, MmapOptions};
 
-use storage_proofs_core::api_version::ApiVersion;
-
 pub struct CacheReader<T> {
     file: File,
     bufs: UnsafeCell<[Mmap; 2]>,
@@ -22,7 +20,6 @@ pub struct CacheReader<T> {
     window_size: usize,
     cursor: IncrementingCursor,
     consumer: AtomicU64,
-    api_version: ApiVersion,
     _t: PhantomData<T>,
 }
 
@@ -96,12 +93,7 @@ impl IncrementingCursor {
 }
 
 impl<T: FromByteSlice> CacheReader<T> {
-    pub fn new(
-        filename: &Path,
-        window_size: Option<usize>,
-        degree: usize,
-        api_version: ApiVersion,
-    ) -> Result<Self> {
+    pub fn new(filename: &Path, window_size: Option<usize>, degree: usize) -> Result<Self> {
         info!("initializing cache");
         let file = File::open(filename)?;
         let size = File::metadata(&file)?.len() as usize;
@@ -134,7 +126,6 @@ impl<T: FromByteSlice> CacheReader<T> {
             // The furthest window from which the cache has yet been read.
             cursor: IncrementingCursor::new(0),
             consumer: AtomicU64::new(0),
-            api_version,
             _t: PhantomData::<T>,
         })
     }
@@ -195,10 +186,6 @@ impl<T: FromByteSlice> CacheReader<T> {
         Ok(())
     }
 
-    pub fn api_version(&self) -> ApiVersion {
-        self.api_version
-    }
-
     fn map_buf(offset: u64, len: usize, file: &File) -> Result<Mmap> {
         unsafe {
             MmapOptions::new()
@@ -313,9 +300,8 @@ pub fn setup_create_label_memory(
     degree: usize,
     window_size: Option<usize>,
     cache_path: &Path,
-    api_version: ApiVersion,
 ) -> Result<(CacheReader<u32>, MmapMut, MmapMut)> {
-    let parents_cache = CacheReader::new(cache_path, window_size, degree, api_version)?;
+    let parents_cache = CacheReader::new(cache_path, window_size, degree)?;
     let layer_labels = allocate_layer(sector_size)?;
     let exp_labels = allocate_layer(sector_size)?;
 
